@@ -16,7 +16,6 @@
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
-#include <gtk/gtk.h>
 #include <gxw/gxinit.h>
 #include "config.h"
 
@@ -60,6 +59,7 @@ GType gx_paint_func_get_type(void)
 			{24, "ir_expose", "ir_expose" },
 			{25, "main_expose", "main_expose" },
 			{26, "level_meter_expose", "level_meter_expose" },
+            {27, "cab_expose", "cab_expose" },
 			{ 0, NULL, NULL }
 		};
 		etype = g_enum_register_static (g_intern_static_string ("GxPaintFunc"), values);
