@@ -17,8 +17,6 @@
  */
 
 #include "GxSimpleValueDisplay.h"
-#include <gtk/gtkmain.h>
-#include <gtk/gtkprivate.h>
 
 #define P_(s) (s)   // FIXME -> gettext
 
@@ -64,7 +62,8 @@ static gboolean gx_simple_value_display_expose(GtkWidget *widget, GdkEventExpose
 static gboolean gx_simple_value_display_button_press (GtkWidget *widget, GdkEventButton *event)
 {
 	g_assert(GX_IS_SIMPLE_VALUE_DISPLAY(widget));
-	if (event->button != 1 && event->button != 3) {
+	gtk_widget_grab_focus(widget);
+	if (event->button != 3) {
 		return FALSE;
 	}
 	GdkRectangle image_rect, value_rect;
