@@ -17,9 +17,6 @@
  */
 
 #include "GxToggleImage.h"
-#include <gtk/gtktogglebutton.h>
-#include <gtk/gtkprivate.h>
-#include <gdk/gdkpixbuf.h>
 
 #define P_(s) (s)   // FIXME -> gettext
 
@@ -57,7 +54,7 @@ static void gx_toggle_image_class_init(GxToggleImageClass *klass)
 		                    P_("Image base name"),
 		                    P_("Base name of the image, append \"_on\" and \"_off\" for the stock names"),
 		                    "switch",
-		                    GParamFlags(GTK_PARAM_READWRITE)));
+		                    GParamFlags(G_PARAM_READWRITE|G_PARAM_STATIC_STRINGS)));
 }
 
 static void gx_toggle_image_init(GxToggleImage *toggle_image)
@@ -104,9 +101,10 @@ static gboolean gx_toggle_image_expose(GtkWidget *widget, GdkEventExpose *event)
 	}
 	int x = widget->allocation.x + (widget->allocation.width - gdk_pixbuf_get_width(img))/2;
 	int y = widget->allocation.y + (widget->allocation.height - gdk_pixbuf_get_height(img))/2;
-	gdk_draw_pixbuf(gtk_widget_get_window(widget), widget->style->fg_gc[0], img,
-	                       0, 0, x, y, -1, -1,
-	                       GDK_RGB_DITHER_NORMAL, 0, 0);
+	cairo_t *cr = gdk_cairo_create(gtk_widget_get_window(widget));
+	gdk_cairo_set_source_pixbuf (cr, img, x, y);
+	cairo_paint (cr);
+	cairo_destroy (cr);
 	g_object_unref(img);
 	return FALSE;
 }
