@@ -49,6 +49,8 @@ static image_entry image_data[] = {
 	{ "rbutton_off", pb_rbutton_off },
 	{ "prbutton_on", pb_prbutton_on },
 	{ "prbutton_off", pb_prbutton_off },
+	{ "fbutton_on", pb_fbutton_on },
+	{ "fbutton_off", pb_fbutton_off },
 	{ "vslider", pb_vslider },
 	{ "wheel_back", pb_wheel_back },
     { "wheel_vertical_back", pb_wheel_vertical_back },
@@ -75,6 +77,7 @@ void gxw_init()
 #if !GLIB_CHECK_VERSION(2, 36, 0) 
 	g_type_init();
 #endif
+G_GNUC_BEGIN_IGNORE_DEPRECATIONS
 	GtkIconFactory *factory = gtk_icon_factory_new();
 	for (image_entry *p = image_data; p->icon_name; p++) {
 		gtk_icon_factory_add(
@@ -85,3 +88,4 @@ void gxw_init()
 	}
 	gtk_icon_factory_add_default(factory);
 }
+G_GNUC_END_IGNORE_DEPRECATIONS
