@@ -129,6 +129,7 @@ GxJack::GxJack(gx_engine::GxEngine& engine_)
       session_ins(),
       shutdown(),
       connection() {
+	for(int i = 0;i<5;i++) mmessage.send_cc[i] = false;
     connection_queue.new_data.connect(sigc::mem_fun(*this, &GxJack::fetch_connection_data));
     client_change_rt.connect(client_change);
     GxExit::get_instance().signal_exit().connect(
@@ -401,7 +402,7 @@ void GxJack::gx_jack_cleanup() {
     jack_port_unregister(client, ports.input.port);
     jack_port_unregister(client, ports.midi_input.port);
     jack_port_unregister(client, ports.insert_out.port);
-#ifdef USE_MIDI_OUT
+#if defined(USE_MIDI_OUT) || defined(USE_MIDI_CC_OUT)
     jack_port_unregister(client, ports.midi_output.port);
 #endif
     jack_port_unregister(client_insert, ports.insert_in.port);
@@ -512,7 +513,7 @@ void GxJack::gx_jack_init_port_connection(const gx_system::CmdlineOptions& opt)
 	}
     }
 
-#ifdef USE_MIDI_OUT
+#if defined(USE_MIDI_OUT) || defined(USE_MIDI_CC_OUT)
     // autoconnect midi output port
     list<string>& lmo = ports.midi_output.conn;
     for (list<string>::iterator i = lmo.begin(); i != lmo.end(); ++i) {
@@ -579,7 +580,7 @@ void GxJack::gx_jack_callbacks() {
 	client, "midi_in_1", JACK_DEFAULT_MIDI_TYPE, JackPortIsInput, 0);
     ports.insert_out.port = jack_port_register(
 	client, "out_0", JACK_DEFAULT_AUDIO_TYPE, JackPortIsOutput, 0);
-#ifdef USE_MIDI_OUT
+#if defined(USE_MIDI_OUT) || defined(USE_MIDI_CC_OUT)
     ports.midi_output.port = jack_port_register(
 	client, "midi_out_1", JACK_DEFAULT_MIDI_TYPE, JackPortIsOutput, 0);
 #else
@@ -614,6 +615,31 @@ void GxJack::gx_jack_callbacks() {
  ** jack process callbacks
  */
 
+void __rt_func GxJack::process_midi_cc(void *buf, jack_nframes_t nframes) {
+	// midi CC output processing
+	for(int i = 0;i<5;i++) {
+		if (mmessage.send_cc[i]) {
+			unsigned char* midi_send = jack_midi_event_reserve(buf, i, mmessage.me_num[i]);
+
+			if (midi_send) {
+				if (mmessage.me_num[i] == 2) {
+					// program value
+					midi_send[1] =  mmessage.pg_num[i];
+					// controller+ channel
+					midi_send[0] = mmessage.cc_num[i] | 0;
+				} else if (mmessage.me_num[i] == 3) {
+					midi_send[2] =  mmessage.bg_num[i];
+					// program value
+					midi_send[1] =  mmessage.pg_num[i];
+					// controller+ channel
+					midi_send[0] = mmessage.cc_num[i] | 0;
+				}
+			}
+			mmessage.send_cc[i] = false;
+		}
+    }
+}
+
 // must only be used inside gx_jack_process
 void *GxJack::get_midi_buffer(jack_nframes_t nframes) {
     if (!ports.midi_output.port) {
@@ -663,6 +689,10 @@ int __rt_func GxJack::gx_jack_process(jack_nframes_t nframes, void *arg) {
         self.old_transport_state = self.transport_state;
     }
     }
+    // midi CC output processing
+    void *buf = self.get_midi_buffer(nframes);
+    self.process_midi_cc(buf, nframes);
+
     gx_system::measure_pause();
     self.engine.mono_chain.post_rt_finished();
     return 0;
@@ -786,6 +816,19 @@ void GxJack::gx_jack_portconn_callback(jack_port_id_t a, jack_port_id_t b, int c
  ** callbacks: portreg, buffersize, samplerate, shutdown, xrun
  */
 
+void GxJack::send_midi_cc(int _cc, int _pg, int _bgn, int _num) {
+	for(int i = 0;i<5;i++) {
+		if (!mmessage.send_cc[i]) {
+			mmessage.send_cc[i] = true;
+			mmessage.cc_num[i] = _cc;
+			mmessage.pg_num[i] = _pg;
+			mmessage.bg_num[i] = _bgn;
+			mmessage.me_num[i] = _num;
+			return;
+		}
+	}
+}
+
 // ----- fetch available jack ports other than gx_head ports
 // jackd1: RT process thread
 // jackd2: not RT thread
