@@ -381,14 +381,23 @@ string JsonParser::readstring() {
 
 string JsonParser::readnumber(char c) {
     ostringstream os("");
+    static int count_dn = 0;
     do {
         os << c;
         c = is->peek();
         switch (c) {
         case '+': case '-': case '0': case '1': case '2': case '3': case '4':
         case '5': case '6': case '7': case '8': case '9': case 'e': case 'E':
-        case '.':
+        case '.': 
             break;
+        // read denormal value
+        case 'n': case 'a': case 'i': case 'f':
+			++count_dn;
+			if (count_dn >=3) {
+				gx_print_warning("JsonParser", "DENORMAL VALUE DETECTED");
+				count_dn = 0;
+			}
+			break;
         default:
             return os.str();
         }
@@ -417,17 +426,6 @@ JsonParser::token JsonParser::read_value_token(char c) {
     if (next_str == "false") {
 	return value_false;
     }
-    // sanitize bad input
-    if (next_str == "nan" || next_str == "inf") {
-	assert(false);
-	next_str = "1e50";
-	return value_number;
-    }
-    if (next_str == "-nan" || next_str == "-inf") {
-	assert(false);
-	next_str = "-1e50";
-	return value_number;
-    }
     return no_token;
 }
 
@@ -462,7 +460,7 @@ void JsonParser::read_next() {
 
         case '"':
             next_str = readstring();
-            *is >> c;
+             *is >> c;
             if (!is->good())
                 throw JsonExceptionEOF("eof");
             if (c == ':') {
@@ -478,6 +476,11 @@ void JsonParser::read_next() {
             next_str = readnumber(c);
             next_tok = value_number;
             break;
+        // read denormal value
+		case 'n': case 'a': case 'i': case 'f':
+            next_str = readnumber(c);
+            next_tok = value_number;
+            break;
 
         default:
 	    next_tok = read_value_token(c);
@@ -1682,7 +1685,7 @@ void PresetBanks::reorder(const std::vector<Glib::ustring>& neworder) {
 }
 
 Glib::ustring PresetBanks::get_name(int n) {
-    for (iterator i = begin(); i != end(); ++i, --n) {
+	for (iterator i = begin(); i != end(); ++i, --n) {
 	if (n == 0) {
 	    return i->get_name();
 	}
@@ -1690,7 +1693,6 @@ Glib::ustring PresetBanks::get_name(int n) {
     return "";
 }
 
-
 /****************************************************************
  ** class GxSettingsBase
  */
