@@ -443,17 +443,25 @@ MidiControllerList::MidiControllerList()
       last_midi_control_value(),
       last_midi_control(-2),
       program_change(-1),
+      mute_change(-1),
+      bank_change(-1),
       time0(0),
       bpm_(9),
       mp(),
       pgm_chg(),
+      mute_chg(),
+      bank_chg(),
       changed(),
       new_program(),
+      new_mute_state(),
+      new_bank(),
       midi_value_changed() {
     for (int i = 0; i < ControllerArray::array_size; ++i) {
 	last_midi_control_value[i] = -1;
     }
     pgm_chg.connect(sigc::mem_fun(*this, &MidiControllerList::on_pgm_chg));
+    mute_chg.connect(sigc::mem_fun(*this, &MidiControllerList::on_mute_chg));
+    bank_chg.connect(sigc::mem_fun(*this, &MidiControllerList::on_bank_chg));
     Glib::signal_timeout().connect(
 	sigc::mem_fun(this, &MidiControllerList::check_midi_values), 60);
 }
@@ -500,6 +508,22 @@ void MidiControllerList::on_pgm_chg() {
     new_program(pgm);
 }
 
+void MidiControllerList::on_mute_chg() {
+    int mute;
+    do {
+	mute = gx_system::atomic_get(mute_change);
+    } while (!gx_system::atomic_compare_and_exchange(&mute_change, mute, -1));
+    new_mute_state(mute);
+}
+
+void MidiControllerList::on_bank_chg() {
+    int bk;
+    do {
+	bk = gx_system::atomic_get(bank_change);
+    } while (!gx_system::atomic_compare_and_exchange(&bank_change, bk, -1));
+    new_bank(bk);
+}
+
 void MidiControllerList::set_config_mode(bool mode, int ctl) {
     assert(mode != get_config_mode());
     if (mode) {
@@ -648,7 +672,15 @@ void MidiControllerList::compute_midi_in(void* midi_input_port_buf, void *arg) {
             gx_system::atomic_set(&program_change, in_event.buffer[1]);
             pgm_chg();
         } else if ((in_event.buffer[0] & 0xf0) == 0xb0) {   // controller
-            set_ctr_val(in_event.buffer[1], in_event.buffer[2]);
+			if (in_event.buffer[1]== 120) { // engine mute by All Sound Off on any midi channel
+				gx_system::atomic_set(&mute_change, in_event.buffer[2]);
+				 mute_chg();
+			} else if (in_event.buffer[1]== 32) { // bank change on any midi channel
+				gx_system::atomic_set(&bank_change, in_event.buffer[2]);
+				 bank_chg();
+			} else {
+				set_ctr_val(in_event.buffer[1], in_event.buffer[2]);
+			}
         } else if ((in_event.buffer[0] ) > 0xf0) {   // midi clock
             if ((in_event.buffer[0] ) == 0xf8) {   // midi beat clock
                 clock_gettime(CLOCK_MONOTONIC, &ts1);
@@ -1093,6 +1125,7 @@ void FloatParameter::readJSON_value(gx_system::JsonParser& jp) {
     json_value = jp.current_value_float();
     if (json_value < lower-abs(5*FLT_EPSILON*lower) || json_value > upper+abs(5*FLT_EPSILON*upper)) {
 	range_warning(json_value, lower, upper);
+	json_value = std_value;
     }
 }
 
