@@ -449,6 +449,7 @@ CmdlineOptions::CmdlineOptions()
       old_user_dir(),
       preset_dir(),
       pluginpreset_dir(),
+      lv2_preset_dir(),
       temp_dir(),
       plugin_dir(),
       loop_dir(),
@@ -457,6 +458,9 @@ CmdlineOptions::CmdlineOptions()
       rpcport(RPCPORT_DEFAULT),
       rpcaddress(),
       onlygui(false),
+      liveplaygui(false),
+      mute(false),
+      setbank(),
       sporadic_overload(0),
       idle_thread_timeout(0),
       convolver_watchdog(true),
@@ -482,7 +486,8 @@ CmdlineOptions::CmdlineOptions()
       system_animations(true),
       system_show_presets(false),
       system_show_toolbar(false),
-      system_show_rack(false) {
+      system_show_rack(false),
+      reload_lv2_presets(true) {
     const char* home = getenv("HOME");
     if (!home) {
 	throw GxFatalError(_("no HOME environment variable"));
@@ -491,6 +496,7 @@ CmdlineOptions::CmdlineOptions()
     plugin_dir = Glib::build_filename(get_user_dir(), "plugins");
     preset_dir = Glib::build_filename(get_user_dir(), "banks");
     pluginpreset_dir = Glib::build_filename(get_user_dir(), "pluginpresets");
+    lv2_preset_dir = Glib::build_filename(get_user_dir(), "pluginpresets/lv2");
     loop_dir = Glib::build_filename(get_pluginpreset_dir(), "loops");
     temp_dir = Glib::build_filename(get_user_dir(), "temp");
     const char *tmp = getenv("GUITARIX2JACK_OUTPUTS1");
@@ -534,11 +540,27 @@ CmdlineOptions::CmdlineOptions()
     opt_onlygui.set_short_name('G');
     opt_onlygui.set_long_name("onlygui");
     opt_onlygui.set_description("start only GUI");
+    Glib::OptionEntry opt_liveplaygui;
+    opt_liveplaygui.set_short_name('L');
+    opt_liveplaygui.set_long_name("liveplaygui");
+    opt_liveplaygui.set_description("start with Live Play GUI");
+    Glib::OptionEntry opt_mute;
+    opt_mute.set_short_name('M');
+    opt_mute.set_long_name("mute");
+    opt_mute.set_description("start with engine muted");
+    Glib::OptionEntry opt_bank;
+    opt_bank.set_short_name('b');
+    opt_bank.set_long_name("bank");
+    opt_bank.set_description("set bank and preset to load at startup");
+    opt_bank.set_arg_description("BANK:PRESET (A:0-Z:9)");
     main_group.add_entry(opt_version, version);
     main_group.add_entry(opt_nogui, nogui);
     main_group.add_entry(opt_rpcport, rpcport);
     main_group.add_entry(opt_rpchost, rpcaddress);
     main_group.add_entry(opt_onlygui, onlygui);
+    main_group.add_entry(opt_liveplaygui, liveplaygui);
+    main_group.add_entry(opt_mute, mute);
+    main_group.add_entry(opt_bank, setbank);
     set_main_group(main_group);
 
     // style options
@@ -849,6 +871,16 @@ void CmdlineOptions::process(int argc, char** argv) {
 	    Glib::OptionError::BAD_VALUE,
 	    _("-c and -r cannot be used together"));
     }
+    if (nogui && liveplaygui) {
+		throw Glib::OptionError(
+	    Glib::OptionError::BAD_VALUE,
+	    _("-N and -L cannot be used together"));
+	}
+    if (onlygui && !setbank.empty()) {
+		throw Glib::OptionError(
+	    Glib::OptionError::BAD_VALUE,
+	    _("-G and -b cannot be used together"));
+	}
     if (lterminal) {
 	GxLogger::get_logger().signal_message().connect(
 	    sigc::ptr_fun(log_terminal));
@@ -863,6 +895,7 @@ void CmdlineOptions::process(int argc, char** argv) {
     make_ending_slash(pixmap_dir);
     make_ending_slash(preset_dir);
     make_ending_slash(pluginpreset_dir);
+    make_ending_slash(lv2_preset_dir);
     make_ending_slash(loop_dir);
     make_ending_slash(temp_dir);
     make_ending_slash(plugin_dir);
