@@ -207,6 +207,7 @@ private:
     static void create_spin_value_(const char *id, const char *label);
     static void create_switch_no_caption_(const char *sw_type,const char * id);
     static void create_feedback_switch_(const char *sw_type,const char * id);
+    static void create_fload_switch_(const char *sw_type,const char * id,const char * idf);
     static void create_switch_(const char *sw_type,const char * id, const char *label);
     static void create_wheel_(const char * id, const char *label);
     static void create_port_display_(const char *id, const char *label);
@@ -1032,6 +1033,10 @@ void CmdConnection::notify(gx_system::JsonStringWriter& jw, const methodnames *m
 	serv.save_state();
     }
 
+    PROCEDURE(sendcc) {
+	serv.jack.send_midi_cc(params[0]->getInt(),params[1]->getInt(),params[2]->getInt(),params[3]->getInt());
+    }
+
     PROCEDURE(setstate) {
 	serv.jack.get_engine().set_state(string_to_engine_state(params[0]->getString()));
 	serv.jack.get_engine().check_module_lists();
@@ -1167,7 +1172,7 @@ bool CmdConnection::request(gx_system::JsonStringParser& jp, gx_system::JsonStri
 	}
     }
     jp.next(gx_system::JsonParser::end_object);
-    const methodnames *p = in_word_set(method.c_str(), method.size());
+    const methodnames *p = Perfect_Hash::in_word_set(method.c_str(), method.size());
     if (!p) {
 	throw RpcError(-32601, Glib::ustring::compose("Method not found -- '%1'", method));
     }
@@ -1357,6 +1362,7 @@ UiBuilderVirt::UiBuilderVirt(gx_system::JsonWriter *jw_, const gx_system::Cmdlin
     create_p_display = create_p_display_;
     create_simple_spin_value = create_simple_spin_value_;
     create_eq_rackslider_no_caption = create_eq_rackslider_no_caption_;
+    create_fload_switch = create_fload_switch_;
     insertSpacer = insertSpacer_;
     set_next_flags = set_next_flags_;
 }
@@ -1533,6 +1539,15 @@ void UiBuilderVirt::create_feedback_switch_(const char *sw_type, const char * id
     jw->end_array();
 }
 
+void UiBuilderVirt::create_fload_switch_(const char *sw_type, const char * id, const char * idf) {
+    jw->begin_array();
+    jw->write("create_fload_switch");
+    jw->write(sw_type);
+    jw->write(id);
+    jw->write(idf);
+    jw->end_array();
+}
+
 void UiBuilderVirt::create_switch_(const char *sw_type, const char * id, const char *label) {
     jw->begin_array();
     jw->write("create_switch");
