@@ -536,7 +536,7 @@ void PortMapWindow::load_all() {
     uslp();
     load(3, jack.ports.midi_input.port);
     uslp();
-#ifdef USE_MIDI_OUT
+#if defined(USE_MIDI_OUT) || defined(USE_MIDI_CC_OUT)
     load(4, jack.ports.midi_output.port);
     uslp();
 #endif
@@ -578,12 +578,16 @@ PortMapWindow::PortMapWindow(Glib::RefPtr<gx_gui::GxBuilder> bld, gx_jack::GxJac
     b->set_name("rack_button");
     Gtk::VBox *vbox1;
     bld->find_widget("dialog-vbox1", vbox1);
-    vbox1->signal_expose_event().connect(
-	sigc::group(&gx_cairo::rectangle_skin_color_expose,GTK_WIDGET(vbox1->gobj()),sigc::_1,(void*)0),false);
+    g_signal_connect(GTK_WIDGET(vbox1->gobj()), "expose-event",
+                     G_CALLBACK(gx_cairo::rectangle_skin_color_expose), NULL);
+   // vbox1->signal_expose_event().connect(
+	//sigc::group(&gx_cairo::rectangle_skin_color_expose,GTK_WIDGET(vbox1->gobj()),sigc::_1,(void*)0),false);
     Gtk::VBox *vbox2;
     bld->find_widget("dialog-vbox2", vbox2);
-    vbox2->signal_expose_event().connect(
-	sigc::group(&gx_cairo::rectangle_skin_color_expose,GTK_WIDGET(vbox2->gobj()),sigc::_1,(void*)0),false);
+    g_signal_connect(GTK_WIDGET(vbox2->gobj()), "expose-event",
+                     G_CALLBACK(gx_cairo::rectangle_skin_color_expose), NULL);
+  //  vbox2->signal_expose_event().connect(
+//	sigc::group(&gx_cairo::rectangle_skin_color_expose,GTK_WIDGET(vbox2->gobj()),sigc::_1,(void*)0),false);
     vbox1->set_redraw_on_allocate(true);
     vbox2->set_redraw_on_allocate(true);
     for (int i = 0; i < number_of_ports; ++i) {
