@@ -118,7 +118,7 @@ GxMachine::GxMachine(gx_system::CmdlineOptions& options_):
         {"Augmented Fourths"},{"Slow Motion"},{"Admiral"},{"Buzzard"},{"Face"},{"Four and Twenty"},{"Ostrich"},{"Capo 200"},
         {"Balalaika"},{"Cittern One"},{"Cittern Two"},{"Dobro"},{"Lefty"},{"Mandoguitar"},{"Rusty Cage"},{"Hardcore"}, {0}};
     pmap.reg_non_midi_enum_par("racktuner.tuning", "Tuning", tuning_labels, (int*)0, false, 0);
-    static const value_pair tuning_temperament[] = {{"12-ET"},{"19-ET"},{"31-ET"}, {0}};
+    static const value_pair tuning_temperament[] = {{"12-ET"},{"19-ET"},{"24-ET"},{"31-ET"},{"53-ET"}, {0}};
     pmap.reg_non_midi_enum_par("racktuner.temperament", "Temperament", tuning_temperament, (int*)0, false, 0);
     pmap.reg_par_non_preset("racktuner.scale_lim", "Limit", 0, 3.0, 1.0, 10.0, 1.0);
     pmap.reg_par_non_preset("ui.tuner_reference_pitch", "?Tuner Reference Pitch", 0, 440, 427, 453, 0.1);
@@ -148,10 +148,16 @@ GxMachine::GxMachine(gx_system::CmdlineOptions& options_):
 
     engine.controller_map.signal_new_program().connect(
 	sigc::mem_fun(this, &GxMachine::do_program_change));
+    engine.controller_map.signal_new_mute_state().connect(
+	sigc::mem_fun(this, &GxMachine::set_mute_state));
+    engine.controller_map.signal_new_bank().connect(
+	sigc::mem_fun(this, &GxMachine::do_bank_change));
     pmap["ui.live_play_switcher"].signal_changed_bool().connect(
 	sigc::mem_fun(this, &GxMachine::edge_toggle_tuner));
     engine.midiaudiobuffer.signal_jack_load_change().connect(
 	sigc::mem_fun(this, &GxMachine::on_jack_load_change));
+    switch_bank = settings.get_current_bank();
+
 }
 
 GxMachine::~GxMachine() {
@@ -179,20 +185,47 @@ void GxMachine::edge_toggle_tuner(bool v) {
 
 void GxMachine::do_program_change(int pgm) {
     Glib::ustring bank = settings.get_current_bank();
+    if ((bank != switch_bank) && !switch_bank.empty()) {
+        bank = switch_bank;
+	}
     bool in_preset = !bank.empty();
     gx_system::PresetFile *f;
     if (in_preset) {
-	f = settings.banks.get_file(bank);
-	in_preset = pgm < f->size();
+        f = settings.banks.get_file(bank);
+        in_preset = pgm < f->size();
     }
     if (in_preset) {
-	settings.load_preset(f, f->get_name(pgm));
+        settings.load_preset(f, f->get_name(pgm));
+        set_parameter_value("system.current_bank",bank);
 	if (engine.get_state() == gx_engine::kEngineBypass) {
 	    engine.set_state(gx_engine::kEngineOn);
 	}
-    } else if (engine.get_state() == gx_engine::kEngineOn) {
-	engine.set_state(gx_engine::kEngineBypass);
-    }
+    } // do nothing when bank/preset is out of range
+    // else if (engine.get_state() == gx_engine::kEngineOn) {
+	// engine.set_state(gx_engine::kEngineBypass);
+    //}
+}
+
+void GxMachine::reset_switch_bank() {
+	switch_bank = settings.get_current_bank();
+}
+
+void GxMachine::do_bank_change(int pgm) {
+	if (!get_bank_name(pgm).empty()) {
+		switch_bank = get_bank_name(pgm);
+		Glib::signal_timeout().connect_once(
+		    sigc::mem_fun(this,&GxMachine::reset_switch_bank), 50);
+	} else {
+		switch_bank = settings.get_current_bank();
+	}
+}
+
+void GxMachine::set_mute_state(int mute) {
+	if (mute == 0) {
+		engine.set_state(gx_engine::kEngineOn);
+	} else  {
+		engine.set_state(gx_engine::kEngineOff);
+	}
 }
 
 void GxMachine::set_state(GxEngineState state) {
@@ -422,18 +455,49 @@ Glib::ustring GxMachine::get_bank_name(int n) {
     return settings.banks.get_name(n);
 }
 
+int GxMachine::get_bank_num(Glib::ustring num) {
+    Glib::ustring array = "abcdefghijklmnopqrstuvwxyz" ;
+    int i = 0;
+	for(i=0;i<26;i++) {
+		if(num.compare(array.substr(i,1))==0) break;
+	}
+	return bank_size() -i -1;
+}
+
+void GxMachine::msend_midi_cc(int cc, int pgn, int bgn, int num) {
+	jack.send_midi_cc(cc, pgn, bgn, num);
+}
+
 void GxMachine::load_preset(gx_system::PresetFileGui *pf, const Glib::ustring& name) {
+    int n = get_bank_index(get_current_bank());
     settings.load_preset(pf, name);
+#ifdef USE_MIDI_CC_OUT
+    if (get_bank_index(pf->get_name()) != n) {
+        msend_midi_cc(0xB0, 32, get_bank_index(pf->get_name()),3);
+    }
+    msend_midi_cc(0xC0, pf->get_index(name),0,2);
+#endif
 }
 
 void GxMachine::loadstate() {
     settings.loadstate();
+	if (!options.get_setbank().empty()) {
+		Glib::ustring sbank = options.get_setbank();
+		int bl = get_bank_num(sbank.substr(0,1).lowercase());
+		int pgm = max(0,atoi(sbank.substr(2,Glib::ustring::npos).raw().c_str())-1);
+		switch_bank = settings.banks.get_name(bl);
+		do_program_change(pgm);
+    }
 }
 
 int GxMachine::bank_size() {
     return settings.banks.size();
 }
 
+int GxMachine::get_bank_index(const Glib::ustring& bank) {
+    return settings.banks.get_index(bank);
+}
+
 void GxMachine::create_default_scratch_preset() {
     settings.create_default_scratch_preset();
 }
@@ -1520,6 +1584,11 @@ int GxMachineRemote::load_remote_ui(const UiBuilder& builder, int form) {
 	} else if (jp->current_value() == "create_feedback_switch") {
 	    std::string sw_type = next_char_pointer(jp);
 	    builder.create_feedback_switch(sw_type.c_str(), next_char_pointer(jp));
+	} else if (jp->current_value() == "create_fload_switch") {
+	    std::string sw_type = next_char_pointer(jp);
+	    std::string id = next_char_pointer(jp);
+	    std::string idf = next_char_pointer(jp);
+	    builder.create_fload_switch(sw_type.c_str(), id.c_str(), idf.c_str());
 	} else if (jp->current_value() == "create_switch") {
 	    std::string sw_type = next_char_pointer(jp);
 	    std::string id = next_char_pointer(jp);
@@ -1788,11 +1857,27 @@ Glib::ustring GxMachineRemote::get_bank_name(int n) {
     return banks.get_name(n);
 }
 
+void GxMachineRemote::msend_midi_cc(int cc, int pgn, int bgn, int num) {
+	START_NOTIFY(sendcc);
+    jw->write(cc);
+    jw->write(pgn);
+    jw->write(bgn);
+    jw->write(num);
+    SEND();
+}
+
 void GxMachineRemote::load_preset(gx_system::PresetFileGui *pf, const Glib::ustring& name) {
+    int n = get_bank_index(get_current_bank());
     START_NOTIFY(setpreset);
     jw->write(pf->get_name());
     jw->write(name);
     SEND();
+#ifdef USE_MIDI_CC_OUT
+    if (get_bank_index(pf->get_name()) != n) {
+        msend_midi_cc(0xB0, 32, get_bank_index(pf->get_name()),3);
+    }
+    msend_midi_cc(0xC0, pf->get_index(name),0,2);
+#endif
 }
 
 void GxMachineRemote::loadstate() {
@@ -1803,6 +1888,10 @@ int GxMachineRemote::bank_size() {
     return banks.size();
 }
 
+int GxMachineRemote::get_bank_index(const Glib::ustring& bank) {
+    return banks.get_index(bank);
+}
+
 void GxMachineRemote::create_default_scratch_preset() {
     /* noop */
 }
