@@ -67,6 +67,8 @@
 #include <gtkmm.h>
 
 #include "engine.h"
+#include "jsonrpc.h"
+#include "machine.h"
 
 #include "gx_cairo_callbacks.h"
 
@@ -81,6 +83,7 @@
 #include "gx_jconv_settings.h"
 #include "gx_stackbox_builder.h"
 #include "gx_preset_window.h"
+#include "ladspalist.h"
 #include "gx_main_window.h"
 
 #endif  // SRC_HEADERS_GUITARIX_H_
