@@ -100,11 +100,20 @@ extern "C" {
 }
 #endif
 
+struct midi_cc {
+	bool send_cc[5];
+	int cc_num[5];
+	int pg_num[5];
+	int bg_num[5];
+	int me_num[5];
+};
+
 class GxJack: public sigc::trackable {
  private:
     gx_engine::GxEngine& engine;
     bool                jack_is_down;
     bool                jack_is_exit;
+    midi_cc             mmessage;
     static int          gx_jack_srate_callback(jack_nframes_t, void* arg);
     static int          gx_jack_xrun_callback(void* arg);
     static int          gx_jack_buffersize_callback(jack_nframes_t, void* arg);
@@ -180,6 +189,8 @@ public:
 					   int wait_after_connect, const gx_system::CmdlineOptions& opt);
     float               get_last_xrun() { return last_xrun; }
     void*               get_midi_buffer(jack_nframes_t nframes);
+    void                send_midi_cc(int cc_num, int pgm_num, int bgn, int num);
+    void                process_midi_cc(void *buf, jack_nframes_t nframes);
 
     void                read_connections(gx_system::JsonParser& jp);
     void                write_connections(gx_system::JsonWriter& w);
