@@ -24,6 +24,7 @@
 /****************************************************************
  ** class PresetWindow
  */
+#include <webkit/webkit.h>
 
 class PresetStore: public Gtk::ListStore {
 public:
@@ -101,6 +102,7 @@ private:
     Gtk::Button *save_preset;
     Gtk::Button *new_preset_bank;
     Gtk::ToggleButton *organize_presets;
+    Gtk::Button *online_preset;
     MyTreeView *bank_treeview;
     Gtk::CellRendererText *bank_cellrenderer;
     MyTreeView *preset_treeview;
@@ -139,6 +141,12 @@ private:
     bool is_row_separator(const Glib::RefPtr<Gtk::TreeModel>& model, const Gtk::TreeModel::iterator& iter);
     void on_new_bank();
     void on_preset_save();
+    void on_online_preset();
+    void show_online_preset();
+    const std::string pdir() { return options.get_preset_dir();}
+    static bool downloadRequested(WebKitWebView* webView, WebKitDownload *download,gpointer data );
+    static bool insertRequested(const char* uri, gpointer data );
+    static void download_status(GObject* object, GParamSpec* pspec, gpointer data);
     bool on_bank_drag_motion(const Glib::RefPtr<Gdk::DragContext>& context, int x, int y, guint timestamp);
     void on_bank_drag_data_received(const Glib::RefPtr<Gdk::DragContext>& context, int x, int y, const Gtk::SelectionData& data, guint info, guint timestamp);
     void on_bank_drag_data_get(const Glib::RefPtr<Gdk::DragContext>& context, Gtk::SelectionData& selection, int info, int timestamp);
