@@ -51,20 +51,25 @@ inline unsigned int get_fpu_status_bits() {
 /* On Intel set FZ (Flush to Zero) and DAZ (Denormals Are Zero)
    flags to avoid costly denormals */
 #ifdef __SSE3__
+#ifndef _X86INTRIN_H_INCLUDED
 #include <pmmintrin.h>
+#endif //ndef
 inline void AVOIDDENORMALS() {
     _MM_SET_FLUSH_ZERO_MODE(_MM_FLUSH_ZERO_ON);
     _MM_SET_DENORMALS_ZERO_MODE(_MM_DENORMALS_ZERO_ON);
 }
 #else
+#ifndef _X86INTRIN_H_INCLUDED
 #include <xmmintrin.h>
+#endif //ndef
 inline void AVOIDDENORMALS() { _MM_SET_FLUSH_ZERO_MODE(_MM_FLUSH_ZERO_ON); }
 #endif //__SSE3__
 
 #else
-
+#ifndef _X86INTRIN_H_INCLUDED
 inline void _MM_SET_EXCEPTION_STATE(unsigned int __mask) {}
 inline unsigned int _MM_GET_EXCEPTION_STATE(void) { return 0; }
+#endif //ndef
 inline void AVOIDDENORMALS() {}
 
 #endif //__SSE__
@@ -399,6 +404,7 @@ private:
     std::string old_user_dir;
     std::string preset_dir;
     std::string pluginpreset_dir;
+    std::string lv2_preset_dir;
     std::string temp_dir;
     std::string plugin_dir;
     std::string loop_dir;
@@ -407,6 +413,9 @@ private:
     int rpcport;
     Glib::ustring rpcaddress;
     bool onlygui;
+    bool liveplaygui;
+    bool mute;
+    Glib::ustring setbank;
     int sporadic_overload;
     int idle_thread_timeout;
     bool convolver_watchdog;
@@ -440,6 +449,7 @@ public:
     bool system_show_presets;
     bool system_show_toolbar;
     bool system_show_rack;
+    bool reload_lv2_presets;
 
 public:
     CmdlineOptions();
@@ -454,10 +464,13 @@ public:
     std::string get_temp_filepath(const std::string& basename) const { return temp_dir + basename; }
     std::string get_pluginpreset_filepath(const std::string& id, bool factory) const {
 	return (factory ? factory_dir : pluginpreset_dir) + id; }
+    std::string get_lv2_preset_filepath(const std::string& id) const {
+	return (lv2_preset_dir) + id; }
     const std::string& get_old_user_dir() const { return old_user_dir; }
     const std::string& get_plugin_dir() const { return plugin_dir; }
     const std::string& get_preset_dir() const { return preset_dir; }
     const std::string& get_pluginpreset_dir() const { return pluginpreset_dir; }
+    const std::string& get_lv2_preset_dir() const { return lv2_preset_dir; }
     const std::string& get_loop_dir() const { return loop_dir; }
     const std::string& get_temp_dir() const { return temp_dir; }
     const std::string& get_factory_dir() const { return factory_dir; }
@@ -465,6 +478,9 @@ public:
     const Glib::ustring& get_rcset() const { return rcset; }
     bool get_clear_rc() const { return clear; }
     bool get_nogui() const { return nogui; }
+    bool get_liveplaygui() const { return liveplaygui; }
+    bool get_mute() const { return mute; }
+    const Glib::ustring& get_setbank() { return setbank; }
     int get_rpcport() const { return rpcport; }
     void set_rpcport(int port) { rpcport = port; }
     const Glib::ustring& get_rpcaddress() { return rpcaddress; }
