@@ -112,8 +112,10 @@ public:
     virtual gx_system::PresetFileGui* get_bank_file(const Glib::ustring& bank) const = 0;
     virtual Glib::ustring get_bank_name(int n) = 0;
     virtual void load_preset(gx_system::PresetFileGui *pf, const Glib::ustring& name) = 0;
+    virtual void msend_midi_cc(int cc, int pgn, int bgn, int num) = 0;
     virtual void loadstate() = 0;
     virtual int bank_size() = 0;
+    virtual int get_bank_index(const Glib::ustring& bank) = 0;
     virtual void create_default_scratch_preset() = 0;
     virtual void set_statefilename(const std::string& fn) = 0;
     virtual void save_to_state(bool preserve_preset=false) = 0;
@@ -224,8 +226,13 @@ private:
     AvahiService *avahi_service;
 #endif
     ParamMap& pmap;
+    Glib::ustring switch_bank;
 private:
+    void reset_switch_bank();
+    int get_bank_num(Glib::ustring num);
+    void set_mute_state(int mute);
     void do_program_change(int pgm);
+    void do_bank_change(int pgm);
     void edge_toggle_tuner(bool v);
     void on_impresp(const std::string& path);
     void exit_handler(bool otherthread);
@@ -286,8 +293,10 @@ public:
     virtual gx_system::PresetFileGui* get_bank_file(const Glib::ustring& bank) const;
     virtual Glib::ustring get_bank_name(int n);
     virtual void load_preset(gx_system::PresetFileGui *pf, const Glib::ustring& name);
+    virtual void msend_midi_cc(int cc, int pgn, int bgn, int num);
     virtual void loadstate();
     virtual int bank_size();
+    virtual int get_bank_index(const Glib::ustring& bank);
     virtual void create_default_scratch_preset();
     virtual void set_statefilename(const std::string& fn);
     virtual void save_to_state(bool preserve_preset=false);
@@ -462,8 +471,10 @@ public:
     virtual gx_system::PresetFileGui* get_bank_file(const Glib::ustring& bank) const;
     virtual Glib::ustring get_bank_name(int n);
     virtual void load_preset(gx_system::PresetFileGui *pf, const Glib::ustring& name);
+    virtual void msend_midi_cc(int cc, int pgn, int bgn, int num);
     virtual void loadstate();
     virtual int bank_size();
+    virtual int get_bank_index(const Glib::ustring& bank);
     virtual void create_default_scratch_preset();
     virtual void set_statefilename(const std::string& fn);
     virtual void save_to_state(bool preserve_preset=false);
